import * as React from 'react';
import {observer} from "mobx-react-lite";
import {HintButtonProps, SelectField, useModelContext, useReadonlyContext} from "@rx-suite/ui";
import {customerSelectionStore} from "../../../hooks/useCustomerSelectionStore";
import {sortedOptions} from "../../../stores/_FieldConstants";
import {t} from "@lingui/macro";
import { useOrderEntryStore } from '../../../hooks/useOrderEntryStore';

export const CustomerOrderSelect:React.FunctionComponent = observer(()=> {
    const orderEntryStore = useOrderEntryStore();
    const readOnly = useReadonlyContext();
    const model = useModelContext();

    const hint = {
        title: t`Customer`,
        text: t`The customer the order is for`} as HintButtonProps;
    const options = customerSelectionStore.userCustomers.map(c => {
        return {
            label: c.display_name,
            value: c.getId().toString()
        }
    });

    React.useEffect(() => {
        if(!readOnly) {
            orderEntryStore.order?.nestedAssignment("customer_id", parseInt(customerSelectionStore.currentCustomerId));
        }
    }, [readOnly, orderEntryStore.order, customerSelectionStore.currentCustomerId]);

    const handleChange = React.useCallback((name: string | undefined, newCustomerId: string | string[]) => {
        customerSelectionStore.handleCurrentCustomerChange(name, newCustomerId);
    }, [orderEntryStore.order, customerSelectionStore.currentCustomerId]);

    return (
        <SelectField
            value={model.viewModel.dig("customer_id").toString()}
            onChange={handleChange}
            options={sortedOptions(options)}
            disabled={readOnly}
            hint={hint}/>
    )
});
