import {InputField, useModelContext, useReadonlyContext} from '@rx-suite/ui';
import {observer} from 'mobx-react-lite';
import * as React from 'react';
import {OrderFieldProps} from "../../../stores/_FieldConstants";
import {OrderModel} from "../../../stores/OrderStore";
import {useOrderEntryStore} from "../../../hooks/useOrderEntryStore";

export const ManufacturerUPCField: React.FunctionComponent<OrderFieldProps> = observer(({
                                                                                            name,
                                                                                            label,
                                                                                            disabled,
                                                                                        }) => {
    const store = useOrderEntryStore();
    const model = useModelContext() as OrderModel;
    const readOnly = useReadonlyContext();

    const handleChange = React.useCallback(e => {
        model.nestedAssignment(e.target.name, e.target.value);
    }, [model]);

    const handleBlur = React.useCallback(() => {
        model.validate();
        store.findFramesByUPC(model.viewModel.dig(name));
    }, [model, name, store]);

    return (
        <InputField
            disabled={disabled || readOnly}
            label={label}
            name={name}
            value={model.viewModel.dig(name) || ''}
            onChange={handleChange}
            onBlur={handleBlur}
            error={!!model.errors[name]}
            helperText={model.errors[name]}
            fullWidth
        />
    )
});