import * as React from 'react';
import {observer} from "mobx-react-lite";
import {useModelContext} from "@rx-suite/ui";
import {OrderFieldProps, horizontalOptions, verticalOptions} from "../../../stores/_FieldConstants";
import {GenericInput} from "./GenericInput";
import {useState} from "react";

export const PrismAxisField: React.FunctionComponent<OrderFieldProps> = observer(({
                                                                                      options,
                                                                                      disabled,
                                                                                      eye,
                                                                                      ...props
                                                                                  }) => {
    const model = useModelContext();
    const [isDisabled, setIsDisabled] = useState<boolean>(true);
    const [filteredOptions, setFilteredOptions] = useState<{code: string, desc:any}[]>([]);

    React.useEffect(() => {
        const firstAxis = model.viewModel.dig(`raw_data.${eye}PRVA1`);
        const isDir = horizontalOptions.includes(firstAxis) || verticalOptions.includes(firstAxis)

        setIsDisabled(!isDir);
        if (isDir) {
            let omittedOptions: string[];
            if (horizontalOptions.includes(firstAxis)) {
                omittedOptions = ["In", "Out"];
            } else {
                omittedOptions = ["Up", "Down"];
            }

            setFilteredOptions(options!.filter(o => !omittedOptions.includes(o.code)))
        } else {
            model.viewModel.nestedAssignment(`raw_data.${eye}PRVM2`, '')
        }
    }, [model.viewModel.dig(`raw_data.${eye}PRVA1`)])


    return (
        <GenericInput options={filteredOptions} eye={eye} disabled={isDisabled} {...props} />
    );
});