import * as React from 'react';
import {ModelSelect, useReadonlyContext} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {ShippingMethodModel, ShippingMethodStore} from '../../../stores/ShippingMethodStore';
import {sortedOptions} from "../../../stores/_FieldConstants";
import { customerSelectionStore } from '../../../hooks/useCustomerSelectionStore';
import {useOrderEntryStore} from "../../../hooks/useOrderEntryStore";

export const ShippingMethodSelect = observer(() => {
    const orderEntryStore = useOrderEntryStore();
    const readOnly = useReadonlyContext();

    React.useEffect(() => {
        ShippingMethodStore.getData();
    }, []);

    React.useEffect(() => {
        const tmp = async () => {
            if(!orderEntryStore.order) return;
            if(orderEntryStore.order.readOnly) return;

            await customerSelectionStore.currentCustomer?.sync();
            const shippingMethodId = customerSelectionStore.currentCustomer?.currentShippingMethodId;

            if(shippingMethodId) {
                orderEntryStore.order.viewModel.nestedAssignment("shipping_methods_id", shippingMethodId.toString());
            } else {
                orderEntryStore.order.viewModel.nestedAssignment("shipping_methods_id", "");
            }
        }

        if(!readOnly) {
            tmp();
        }


    }, [orderEntryStore.order, customerSelectionStore.currentCustomerId]);

    const shipping_methods = ShippingMethodStore.models as ShippingMethodModel[];
    const options = shipping_methods.filter(sm => {
        return sm.description.length > 0;
    }).map(sm => {
        return {
            label: sm.description,
            value: sm.getId().toString()
        }
    });

    return (
        <ModelSelect
            name={"shipping_methods_id"}
            options={sortedOptions(options)}
            loading={!!customerSelectionStore.currentCustomer?.syncing}
        />
    );
});