import * as React from 'react';
import {ModelSelect, useModelContext, useReadonlyContext} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {StyleTypeModel, StyleTypeStore} from "../../../stores/StyleTypeStore";
import {sortedOptions} from "../../../stores/_FieldConstants";

export const StyleTypeSelect = observer(() => {
    const model = useModelContext();
    const readOnly = useReadonlyContext();

    React.useEffect(() => {
        StyleTypeStore.getData();
    }, [])

    const style_types = StyleTypeStore.models as StyleTypeModel[];
    const options = style_types.map(st => {
        return {
            label: st.style_type,
            value: st.getId()
        }
    })

    return (
        <ModelSelect
            name={"style_type_id"}
            disabled={!!model.viewModel.quick_code_id || readOnly}
            options={sortedOptions(options)}
            loading={StyleTypeStore.isLoading}
            error={!!StyleTypeStore.fetchErr || !!model.errors.style_type_id}
            helperText={StyleTypeStore.fetchErr || model.errors.style_type_id}
        />
    )
});