import {observer} from 'mobx-react-lite';
import * as React from 'react';
import {ButtonField} from "@rx-suite/ui";
import {t, Trans} from "@lingui/macro";
import {moduleIsInstalled} from "@rx-suite/stores";
import {FrameLookupDialog} from "./FrameLookupDialog";
import {useOrderEntryStore} from "../../../hooks/useOrderEntryStore";
import {FrameFindUPCInput} from "./FrameFindUPCInput";
import {makeStyles, Typography} from "@material-ui/core";
import {Web} from "@material-ui/icons";

const useStyles = makeStyles(() => ({
    wrapper: {
        width: '100%',
        display: 'flex',
        alignItems: 'baseline'
    },
    scanField: {
        flexGrow: 1
    }
}));

export const FrameLookupButton = observer(() => {
    const store = useOrderEntryStore();
    const classes = useStyles();
    if (!moduleIsInstalled('rx_inventory') || !store.canPickFrame) {
        return null;
    }

    return <>
        <div className={classes.scanField}>
            <FrameFindUPCInput/>
        </div>
        <Typography><Trans>or</Trans></Typography>
        <ButtonField text={t`Browse Frames`}
                     onClick={store.showFrameDialog}
                     startIcon={<Web/>}
        />
        <FrameLookupDialog/>
    </>
});