import {dataStorePermission, RouteDefinition} from "@rx-suite/ui";
import {Build, List, ListAlt, Settings, Speed, Tune} from '@material-ui/icons';
import {OrderStore} from "./stores/OrderStore";
import {OrdersBreadModel} from "./pages/orders/OrdersBreadModel";
import {QuickCodePage} from "./pages/quick_codes/QuickCodePage";
import {ConfigPage} from "./pages/config/ConfigPage";
import {QuickCodeStore} from "./stores/QuickCodeStore";
import {LabMaintenanceForm} from "./pages/lab_maintenance/LabMaintenanceForm";
import {LabMaintenanceStore} from "./stores/LabMaintenanceStore";
import {Redirect} from "react-router-dom";
import {t} from "@lingui/macro";
import {CurrentUserStore} from "@rx-suite/stores";
import {Maintenance} from "./pages/maintenance/Maintenance";
import {ConfigCustomerBreadModel} from "./pages/config/ConfigCustomerBreadModel";

export const routes: RouteDefinition[] = [
    {
        label: '',
        to: "/",
        exact: true,
        // @ts-ignore
        Component: Redirect,
        props: {
            to: OrderStore.listLink()
        }
    },
    {
        label: t`Orders`,
        to: "/orders",
        exact: false,
        permission: dataStorePermission(OrderStore),
        Component: OrdersBreadModel,
        hotkey: "ctrl+O",
        hotkeys: [
            { to: "/", title: "Views Orders", id: "View Orders" },
            { hotkey: "ctrl+I", to: "/create", title: "Create Order", id: "Create Order" }
        ],
        Icon: ListAlt
    },
    {
        label: t`Settings`,
        to: "",
        exact: false,
        Icon: Settings,
        shouldMount: () => {
            return !CurrentUserStore.selectedModel?.isNew;
        },
        children: [
            {
                label: t`Quick Codes`,
                to: "/quick_codes",
                exact: false,
                permission: dataStorePermission(QuickCodeStore),
                Component: QuickCodePage,
                Icon: Speed
            },
            {
                label: t`User Config`,
                to: "/config",
                exact: false,
                Component: ConfigPage,
                Icon: Tune
            },
            {
                label: t`Customer List`,
                to: '/customer_list',
                exact: false,
                Component: ConfigCustomerBreadModel,
                Icon: List
            },
            {
                label: "Lab Config",
                help: t`Manage lab specific admin settings`,
                to: "/lab_maintenance",
                exact: false,
                permission: dataStorePermission(LabMaintenanceStore),
                Component: LabMaintenanceForm,
                Icon: Settings
            },
            {
                label: t`Maintenance`,
                to: "/maintenance",
                exact: true,
                permission: {
                    target: "rxuniverse_sync",
                    action: "create",
                },
                Component: Maintenance,
                Icon: Build
            }
        ]
    }
];
