# == Schema Information
#
# Table name: customers
#
#  id                       :bigint           not null, primary key
#  active                   :boolean
#  name                     :string(4000)
#  number                   :string(4000)     not null
#  rpt_1                    :string(4000)
#  rpt_2                    :string(4000)
#  rpt_3                    :string(4000)
#  rpt_4                    :string(4000)
#  rpt_5                    :string(4000)
#  created_at               :datetime         not null
#  updated_at               :datetime         not null
#  ship_method_friday_id    :bigint
#  ship_method_monday_id    :bigint
#  ship_method_saturday_id  :bigint
#  ship_method_sunday_id    :bigint
#  ship_method_thursday_id  :bigint
#  ship_method_tuesday_id   :bigint
#  ship_method_wednesday_id :bigint
#
# Indexes
#
#  index_customers_on_number                    (number) UNIQUE
#  index_customers_on_ship_method_friday_id     (ship_method_friday_id)
#  index_customers_on_ship_method_monday_id     (ship_method_monday_id)
#  index_customers_on_ship_method_saturday_id   (ship_method_saturday_id)
#  index_customers_on_ship_method_sunday_id     (ship_method_sunday_id)
#  index_customers_on_ship_method_thursday_id   (ship_method_thursday_id)
#  index_customers_on_ship_method_tuesday_id    (ship_method_tuesday_id)
#  index_customers_on_ship_method_wednesday_id  (ship_method_wednesday_id)
#
# Foreign Keys
#
#  fk_rails_...  (ship_method_friday_id => shipping_methods.id)
#  fk_rails_...  (ship_method_monday_id => shipping_methods.id)
#  fk_rails_...  (ship_method_saturday_id => shipping_methods.id)
#  fk_rails_...  (ship_method_sunday_id => shipping_methods.id)
#  fk_rails_...  (ship_method_thursday_id => shipping_methods.id)
#  fk_rails_...  (ship_method_tuesday_id => shipping_methods.id)
#  fk_rails_...  (ship_method_wednesday_id => shipping_methods.id)
#
class Customer < ApplicationRecord
  has_many :config_customers, dependent: :destroy
  has_many :configs, through: :config_customers

  has_many :orders, dependent: :destroy

  belongs_to :ship_method_monday, class_name: "ShippingMethod", required: false
  belongs_to :ship_method_tuesday, class_name: "ShippingMethod", required: false
  belongs_to :ship_method_wednesday, class_name: "ShippingMethod", required: false
  belongs_to :ship_method_thursday, class_name: "ShippingMethod", required: false
  belongs_to :ship_method_friday, class_name: "ShippingMethod", required: false
  belongs_to :ship_method_saturday, class_name: "ShippingMethod", required: false
  belongs_to :ship_method_sunday, class_name: "ShippingMethod", required: false
end
